@@ -74,9 +74,13 @@ class _AmqpQueue:
     content_type = "text/x-python"
 
     def __init__(self, queue_name, addr='localhost:5672', \
-                        userid='guest', password='guest', ssl=False, exchange_name='sqs_exchange'):
+                        userid='guest', password='guest', ssl=False, exchange_name='sqs_exchange', binding=None):
         self.addr = addr
         self.queue_name = queue_name
+        if binding:
+            self.binding = binding
+        else:
+            self.binding = queue_name
         self.exchange_name = exchange_name
         self.addr = addr
         self.userid = userid
@@ -195,6 +199,23 @@ class Consumer(_AmqpQueue):
         self.delivery_tag = None
 
 
+class Subscriber(Consumer):
+    '''
+    Receives/consumes messages from a subscription queue. If 3 Subscribers connect to
+    a given Producer, each will have it's own persistent queue, and each queue would
+    recieve a copy of any message the Producer puts out (Fan-out.)
+    '''
+    def __init__(self, *args, **kwargs):
+        _AmqpQueue.__init__(self, *args, **kwargs)
+        self.ch.access_request('/data', active=True, read=True, write=False)
+        self._declare()
+        self.ch.queue_bind(self.queue_name, self.exchange_name, self.binding)
+        self.delivery_tag = None
+
+        self.consumer_tag = self.ch.basic_consume(self.queue_name,
+                                            callback=self._amqp_callback)
+        self._amqp_messages = []
+
 
 
 if __name__ == '__main__':
