@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-from amqpqueue import Producer, Consumer
+from amqpqueue import Producer, Consumer, Subscriber
 
 class QueueFactory(object):
     """Allows you to set defaults for your producer and consumer queues
@@ -48,3 +48,14 @@ class QueueFactory(object):
                         ssl=self.context['ssl'],
                         exchange_name=self.context['exchange_name'])
         
+    def Subscriber(self, queue, binding, **kw):
+        this_context = self.context.copy()
+        for key in kw:
+            this_context[key] = kw[key]
+        return Subscriber(queue, addr=self.context['addr'],
+                        userid=self.context['userid'],
+                        password=self.context['password'],
+                        ssl=self.context['ssl'],
+                        exchange_name=self.context['exchange_name'],
+                        binding=binding)
+        
